CardAuthMethods class

Properties

getName → String
Get payment networks name
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

cryptogram3ds → CardAuthMethods
Device token on an Android device authenticated with a 3-D Secure cryptogram
no setter
panOnly → CardAuthMethods
Cards on file on Google.com linked to user account
no setter