PaymentNetwork class

Properties

getName → String
Get payment networks name
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

amex → PaymentNetwork
Available on iOS and Android
no setter
cartesBancarries → PaymentNetwork
Available only on iOS
no setter
discover → PaymentNetwork
Available on iOS and Android
no setter
eftPos → PaymentNetwork
Available only on iOS
no setter
electron → PaymentNetwork
Available only on iOS
no setter
elo → PaymentNetwork
Available only on iOS
no setter
idCredit → PaymentNetwork
Available only on iOS
no setter
interac → PaymentNetwork
Available on iOS and Android
no setter
jcb → PaymentNetwork
Available on iOS and Android
no setter
mada → PaymentNetwork
Available only on iOS
no setter
maestro → PaymentNetwork
Available only on iOS
no setter
masterCard → PaymentNetwork
Available on iOS and Android
no setter
privateLabel → PaymentNetwork
Available only on iOS
no setter
quicPay → PaymentNetwork
Available only on iOS
no setter
suica → PaymentNetwork
Available only on iOS
no setter
unionPay → PaymentNetwork
Available only on iOS
no setter
visa → PaymentNetwork
Available on iOS and Android
no setter
vPay → PaymentNetwork
Available only on iOS
no setter