ApplePayModel class

Constructors

ApplePayModel(String? type, String? company, String? name, String? number, String? message, String? gatewayId, String? referenceNumber)
ApplePayModel.fromJson(Map<String, dynamic> json)

Properties

company ↔ String?
getter/setter pair
gatewayId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
number ↔ String?
getter/setter pair
referenceNumber ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited