STCPayModel class

Constructors

STCPayModel(String? type, String? mobile, String? referenceNumber, String? branch, String? cashier, String? transactionUrl, String? message)
STCPayModel.fromJson(Map<String, dynamic> json)

Properties

branch ↔ String?
getter/setter pair
cashier ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
getter/setter pair
mobile ↔ String?
getter/setter pair
referenceNumber ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionUrl ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited